Slow HF 8.2.14

Announcement of new releases, bugs, support, suggestions
shutterbug
Posts: 68
Joined: 17.12.2022 15:14

Re: Slow HF 8.2.14

Post by shutterbug »

Catherine wrote: 20.06.2024 12:03
shutterbug wrote: 18.06.2024 19:53 @Catherine: Have you been able to reproduce the issue or find a solution?
There is something wrong with the parallel image loading, yes. It works the first time but not after that. We're investigating, but one of our primary developers is unavailable for another week or two, which is why it's taking longer.
Hey Catherine,

just wanted to ask whether there's been some development regarding the parallel loading issue. I miss the performance of the previous versions :)
User avatar
Catherine
Posts: 1872
Joined: 29.04.2019 23:38

Re: Slow HF 8.2.14

Post by Catherine »

Hi! It's not as simple, I was wrong. I had an impression that it doesn't work, but it actually does, and works well.

Moreover, I cannot reproduce the problem. I'm comparing versions 8.2.12 and 8.2.15 (current latest) without OpenCL on a Mac Mini M1, and getting the exact same rendering times within 1 second (on a rather large RAF stack that takes 114 seconds to render).

With OpenCL the new version is faster, 106 sec vs. 118 in 8.2.12, and the second run is 9 sec vs. 18 in 8.2.12.

P. S. But I might have just found what has actually become slow, hold on, I'll post an update later as we investigate.
In the meantime, turn off the "Show intermediary results" checkbox in the Helicon Focus preferences to make rendering a lot faster.
shutterbug
Posts: 68
Joined: 17.12.2022 15:14

Re: Slow HF 8.2.14

Post by shutterbug »

Intersting. I have the same issue on two different computers (iMac 2019 and MacBook Pro M1) using two different RAW formats (Fuji RAF and Nikon NEF)...

Which formats (and workflows) have you tried to replicate the issue? Did you use the plugin method or direct RAW to DNG stacks?
User avatar
Catherine
Posts: 1872
Joined: 29.04.2019 23:38

Re: Slow HF 8.2.14

Post by Catherine »

Direct, and I don't think it matters. It's the displaying of intermediate images that is slow, turn it off (I edited my previous post, but you have already replied by then).
shutterbug
Posts: 68
Joined: 17.12.2022 15:14

Re: Slow HF 8.2.14

Post by shutterbug »

Thank you so much!

That's really interesting, I had the intermediate images turned off a long time ago and then turned them on to see whether something else was working correctly and had not thought about turning it off again.

I wouldn't have expected that to be the culprit as it behaved as if it had to re-render all the RAW images even after they had already been rendered once - but yeah, looks like that's it! I just tried a 250 RAW to DNG stack and that worked very well and the re-stack was very fast!

Thanks again!!
User avatar
Catherine
Posts: 1872
Joined: 29.04.2019 23:38

Re: Slow HF 8.2.14

Post by Catherine »

shutterbug wrote: 23.07.2024 22:30 it behaved as if it had to re-render all the RAW images even after they had already been rendered once -
That would be the case when there is not enough space on your main disk drive to store all the unpacked images (the one where the cache folder is).
shutterbug
Posts: 68
Joined: 17.12.2022 15:14

Re: Slow HF 8.2.14

Post by shutterbug »

Catherine wrote: 24.07.2024 00:20
shutterbug wrote: 23.07.2024 22:30 it behaved as if it had to re-render all the RAW images even after they had already been rendered once -
That would be the case when there is not enough space on your main disk drive to store all the unpacked images (the one where the cache folder is).
Hm strange, I don't have a full main disk on either computer but from the behaviour (and duration) it did look like it had to re-render each individual RAW file when switching to different rendering algorithms. Now that I've turned off the intermediate images re-rendering an image is much, much faster than before.

Anyway - thanks again, that absolutely solved the issue and it's pretty much as fast as it was before! :)
PerVindis
Posts: 16
Joined: 07.12.2022 17:38

Re: Slow HF 8.2.14

Post by PerVindis »

Just to let you know, that nothing has changed.
The processtime is still veeeery long.
Post Reply